<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;
use \Exception as Exception;

class ProdLoja extends \Teknisa\MAN\Controllers\TeknisaCrud {

	protected $salesMessage;
	protected $produtoService;
    protected $prodLojaService;
    protected $util;
    
    const dataSourcceProdutosLoja = 'ger12300_cadloja_produtos';
    
	public function __construct(Utilities\SalesMessage $salesMessage, Services\Produto $produtoService, Services\ProdLoja $prodLojaService, Utilities\Util $util, $parameterBag) {
		$this->salesMessage            = $salesMessage;
		$this->produtoService 	       = $produtoService;
        $this->prodLojaService         = $prodLojaService;
        $this->util                    = $util; 
        $this->parameterBag            = $parameterBag;
        
	}

    public function getProductProdLoja(Request\Filter $request, Response $response) {
        try {
            $params = $this->util->getParamsAsArray($request);
            $allFields = 'CDARVPROD|NMPRODUTO|NMIMPRPUXA|NMIMPRPROD';
            $nivelInicial = 'NIVELINICIAL';
            if( array_key_exists($allFields, $params)) {
                $paramProducts = $this->produtoService->buscaProdutosProdLoja($params, str_replace('%', '', $params[$allFields]) );
            } else if (array_key_exists($nivelInicial, $params)) { 
                $paramProducts = $this->produtoService->buscaProdutosProdLoja($params, null, $params[$nivelInicial]);
            } else {
                $paramProducts = $this->produtoService->buscaProdutosProdLoja($params);
            }
            
            
            $response->addDataSet(new DataSet('PrinterParamsProducts', $paramProducts));

    	} catch (\Exception $e) {
    		$response->addMessage(new Message($e->getMessage()));
    	}
    }

    // Find Products for Add

    public function saveProd(Request\DataSet $request, Response $response) {
        // You will receive an Array of Zeedhi's Row objects.
        $rows = $this->util->getParamsAsArray($request);
        try {
            foreach ($rows as $row) {
                if($row['__is_new']) {
                    $this->prodLojaService->saveProductsArray($row);
                } else {
                    $this->prodLojaService->updateProduct($row);
                }
            }
        } catch(Exception $e) {
    		$response->addMessage(new Message($e->getMessage()));
        }
    }

    public function updateProduct(Request\Filter $request, Response $response) {
        $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);

        try {
            $this->prodLojaService->updateProduct (
                $params['CDFILIAL'],
                $params['CDLOJA'],
                $params['CDPRODUTO'],
                $params['NRORG'],
                $params['NRORG'],
                $params['CDOPERULTATU'],
                $params['DTULTATU'],
                $params['IDIMPCANITEM'], 
                $params['CDSETOR'], 
                $params['NRSEQIMPRPROD'], 
                $params['NRSEQIMPRPUXA']
            );

            

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function insertProduct(Request\Filter $request, Response $response) {
        
        $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);
        
        try {
            $this->prodLojaService->insertProduct (
                $params['CDFILIAL'],
                $params['CDLOJA'],
                $params['CDPRODUTO'], 
                $params['IDIMPCANITEM'],
                $params['CDSETOR'],
                $params['NRSEQIMPRPROD'], 
                $params['NRSEQIMPRPUXA'],
                $params['NRORG'],
                $params['DTINCLUSAO'],
                $params['CDOPERINCLUSAO']
            );
            

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function deleteProduct(Request\DataSet $request, Response $response) {
        
        // Because of the mass deleting, the first register is 
        // a row with the Filial, Store and Nrorg code.
        $products = $this->util->getParamsAsArray($request);
        $cdfilial = $products[0]['CDFILIAL'];
        $cdloja = $products[0]['CDLOJA'];
        $nrorg = $products[0]['NRORG'];
        
        try {
            $this->prodLojaService->beginTransaction();

            for ($i = 1; $i < count($products) ; $i++) {
                $this->prodLojaService->deleteProduct (
                    $cdfilial,
                    $cdloja,
                    $products[$i]['CDPRODUTO'],
                    $nrorg 
                );
            }

            $this->prodLojaService->commit();

            
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
            $this->prodLojaService->rollBack();
        }
    }

    public function getAreas (Request\Filter $request, Response $response) {
                $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);

        try {

            $areas = $this->prodLojaService->getAreas($params['CDFILIAL'], $params['NRCONFTELA']);
            $response->addDataSet(new DataSet('PrinterParamsAreas', $areas));    

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getProdAreas (Request\Filter $request, Response $response) {
                $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);

        try {

            $prodAreas = $this->prodLojaService->getProdAreas(
                $params['CDFILIAL'],
                $params['CDLOJA'],
                $params['CDPRODUTO']
            );

            $response->addDataSet(new DataSet('PrinterParamsProdAreas', $prodAreas));    

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getConfScreen (Request\Filter $request, Response $response) {
                $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);

        try {

            $confScreens = $this->prodLojaService->getConfScreen(
                $params['CDFILIAL'],
                $params['CDLOJA']
            );

            $response->addDataSet(new DataSet('PrinterParamsConfScreen', $confScreens));    

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function insertProdArea (Request\Filter $request, Response $response) {
                $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);

        try {

            if (!$this->isDuplicateRegister(
                $params['CDFILIAL'],
                $params['CDLOJA'],
                $params['CDPRODUTO'],
                $params['NRCONFTELA'],
                $params['CDAMBIENTE'],
                $params['NRSEQIMPRLOJA']
            )) {

                $NRPRODAMBIENTE = $this->util->newCode('PRODAMBIENTE'.$params['CDFILIAL'].$params['CDLOJA'].$params['CDPRODUTO'], 10);

                $this->prodLojaService->insertProdArea(
                    $params['CDFILIAL'],
                    $params['CDLOJA'],
                    $params['CDPRODUTO'],
                    $NRPRODAMBIENTE,
                    $params['NRCONFTELA'],
                    $params['CDAMBIENTE'],
                    $params['NRSEQIMPRLOJA']
                );

                $prodAreas = $this->prodLojaService->getProdAreas(
                    $params['CDFILIAL'],
                    $params['CDLOJA'],
                    $params['CDPRODUTO']
                );

                
                $response->addDataSet(new DataSet('PrinterParamsProdAreas', $prodAreas));

            } else {
                throw new \Exception($this->salesMessage->getMessage(59));
            }

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    private function isDuplicateRegister ($CDFILIAL, $CDLOJA, $CDPRODUTO, $NRCONFTELA, $CDAMBIENTE, $NRSEQIMPRLOJA) {
        $registers = $this->prodLojaService->getProdAreaDuplicate(
            $CDFILIAL, 
            $CDLOJA, 
            $CDPRODUTO, 
            $NRCONFTELA, 
            $CDAMBIENTE, 
            $NRSEQIMPRLOJA
        );

        return count($registers) > 0;
    }

    public function deleteProdArea (Request\Filter $request, Response $response) {
                $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);

        try {

            $nrProdAreas = json_decode($params['prodAreas'], true);

            $this->prodLojaService->beginTransaction();

            foreach ($nrProdAreas as $NRPRODAMBIENTE) {
                $this->prodLojaService->deleteProdArea(
                    $params['CDFILIAL'],
                    $params['CDLOJA'],
                    $params['CDPRODUTO'],
                    $NRPRODAMBIENTE
                );
            }

            $prodAreas = $this->prodLojaService->getProdAreas(
                $params['CDFILIAL'],
                $params['CDLOJA'],
                $params['CDPRODUTO']
            );

            $this->prodLojaService->commit();

            
            $response->addDataSet(new DataSet('PrinterParamsProdAreas', $prodAreas));

        } catch (\Exception $e) {
            $this->prodLojaService->rollBack();
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function updateProdArea (Request\Filter $request, Response $response) {
                $params = $request->getFilterCriteria()->getConditions();
        $params = $this->util->getParams($params);

        try {

            $this->prodLojaService->updateProdArea(
                $params['NRCONFTELA'],
                $params['CDAMBIENTE'],
                $params['NRSEQIMPRLOJA'],
                $params['CDFILIAL'],
                $params['CDLOJA'],
                $params['CDPRODUTO'],
                $params['NRPRODAMBIENTE']
            );

            $prodAreas = $this->prodLojaService->getProdAreas(
                $params['CDFILIAL'],
                $params['CDLOJA'],
                $params['CDPRODUTO']
            );

            
            $response->addDataSet(new DataSet('PrinterParamsProdAreas', $prodAreas));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    private function unsetValues(array $values, $row){
        foreach($values as $value){
            unset($row[$value]);
        }
        return $row;
    }
    
    public function cadastroAutomaticoProdutosParaLojas (Request\Row $request, Response $response){
       try{
           $valoresParaRetirar = array('NMLOJA','changed','__rightActions','__leftActions');
           $rows = $this->unsetValues($valoresParaRetirar,$request->getRow());
           $this->prodLojaService->cadastroAutomaticoProdutosParaLojas($request->getRow());
       }catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
       }
   }
    
    public function cadastroAutomaticoProdutosNivel (Request\Row $request, Response $response){
       try{
           $valoresParaRetirar = array('NMLOJA','changed','__rightActions','__leftActions');
           $rows = $this->unsetValues($valoresParaRetirar,$request->getRow());
           $this->prodLojaService->cadastroAutomaticoProdutosNivel($request->getRow());
       }catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
       }
   }

}