<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;
use Teknisa\MAN\Factories;


class Filial {
	protected $entityManager;
	protected $util;
	protected $filialFactory;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, Utilities\Util $util, Factories\Filial $filialFactory)  {
		$this->entityManager = $entityManager;
		$this->filialFactory = $filialFactory;
		$this->util = $util;
	}

	public function getFilial($CDFILIAL) {
		$params = array(
			'CDFILIAL' => $CDFILIAL
		);

		$filial = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL, $params);
		return $filial;
	}

	public function getFilialConsumidor($CDFILIAL) {
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_CONSUMIDOR, $params);
	}

	public function alteraPermissaoConsumidor($CDFILIAL, $DSACESSOSITE, $CDTIPOCONS) {
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':DSACESSOSITE' => $DSACESSOSITE,
			':CDTIPOCONS' => $CDTIPOCONS
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::ALTERA_PERMISSAO_CONSUMIDOR, $params);
	}

	public function buscaParametrosVenda($CDFILIAL){
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::BUSCA_PARAMETROS_VENDA_FILIAL, $params);
	}

	public function parametrizarVendaFilialParam($CDFILIAL, $IDUTLQTDPED){
		$params = array(
			':CDFILIAL'    => $CDFILIAL,
			':IDUTLQTDPED' => $IDUTLQTDPED
		);
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::ATUALIZA_PARAVEND_FILIAL_PARAMETRO, $params);
	}

	public function parametrizarVendaFilial($CDFILIAL, $NMFILIAL, $CDINTEGRADOTZ, $DSDIRARQDOTZ){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':NMFILIAL' 	 => $NMFILIAL,
			':CDINTEGRADOTZ' => $CDINTEGRADOTZ,
			':DSDIRARQDOTZ'  => $DSDIRARQDOTZ
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::ATUALIZA_PARAVEND_FILIAL, $params);
	}

	public function getFiliais ($FIRST, $LAST, $LABELFILIAL) {
		$params = array(
			':FIRST' 	 => $FIRST,
			':LAST' 	 => $LAST,
			':LABELFILIAL'  => $LABELFILIAL
		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAIS_MANAGE, $params);
	}

	public function filtroFilial($LABELFILIAL){
		$params = array(
			':LABELFILIAL' => $LABELFILIAL
		);

		$query = Utilities\Query::GET_FILTERED_FILIAIS;

		foreach (array_keys($params) as $name) {
			if(!empty($params[$name])){
				$query = $this->util->putArrayOnQuery($query, $name, $params[$name]);
				$params[$name] = '';
			}
			else{
				$params[$name] = 'null';
			}
		}

		$resultadoFiltrado = $this->entityManager->getConnection()->fetchAll($query, $params);
		return $resultadoFiltrado;
	}

	public function getParaVendDeli ($CDFILIAL) {
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL
		);
		
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_PARAMS_VEND_DELI, $params);
	}

	public function getFilialLojas($CDFILIAL){
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_LOJAS, $params);
	}

	public function getFilialOperadores($CDFILIAL){
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_OPERADORES, $params);
	}
	public function getFilialOperador($CDFILIAL, $CDOPERADOR){
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':CDOPERADOR' => $CDOPERADOR

		);

		$retorno = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_OPERADOR_EXPECIFICO, $params);
		return $retorno[0]['TEMPOPERADOR'];
	}
	public function getLojaOperador($CDFILIAL, $CDLOJA, $CDOPERADOR){
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':CDLOJA' => $CDLOJA,
			':CDOPERADOR' => $CDOPERADOR
		);

		$retorno = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_LOJA_OPERADOR_EXPECIFICO, $params);
		return $retorno[0]['TEMPOPERADOR'];
	}

	public function getLojaOperadores($CDFILIAL, $CDLOJA){
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':CDLOJA' => $CDLOJA,

		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_LOJA_OPERADORES, $params);
	}

	public function loadIntegracoes() {		
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_INTEGRACOES);
	}

	public function loadIntegracao($CDINTEGRACAO) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO
		);	
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_INTEGRACAO, $params);
	}

	public function loadRecebimento($CDINTEGRACAO, $CDTIPORECE) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':CDTIPORECE' 	    => $CDTIPORECE
		);	
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_RECEBIMENTO, $params);
	}

	public function deleteIntegracao($CDINTEGRACAO, $NRORG) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);	
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_INTEGRACAO, $params);
	}

	public function deleteRecebimento($CDINTEGRACAO, $CDTIPORECE, $NRORG) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':CDTIPORECE' 	    => $CDTIPORECE,
			':NRORG' 	        => $NRORG
		);	
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_RECEBIMENTO, $params);
	}

	public function adicionarIntegracao($NMINTEGRACAO, $IDINTEGRACAO, $CDINTEGRACAO, $NRORG){
		$params = array(
			':NMINTEGRACAO'		=> $NMINTEGRACAO,
			':IDINTEGRACAO' 	=> $IDINTEGRACAO, 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);		
		
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::INSERT_INTEGRACAO, $params);	
	}

	public function adicionarRecebimento($CDTIPORECE, $CDTPRECEINTE, $CDINTEGRACAO, $NRORG){
		$params = array(
			':CDTIPORECE'		=> $CDTIPORECE,
			':CDTPRECEINTE' 	=> $CDTPRECEINTE,
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);		
		
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::INSERT_RECEBIMENTO, $params);	
	}

	public function salvarRecebimento($CDTIPORECE, $CDTPRECEINTE, $oldCDTIPORECE, $CDINTEGRACAO, $NRORG){
		$params = array(
			':CDTIPORECE'		=> $CDTIPORECE,
			':CDTPRECEINTE' 	=> $CDTPRECEINTE,
			':oldCDTIPORECE' 	=> $oldCDTIPORECE,
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::UPDATE_RECEBIMENTO, $params);	
	}
	
	public function validaCodigoExterno($CDTPRECEINTE, $CDTIPORECE, $CDINTEGRACAO) {
		$params = array(
			':CDTPRECEINTE' => $CDTPRECEINTE,
			':CDTIPORECE'   => $CDTIPORECE,
			':CDINTEGRACAO' => $CDINTEGRACAO
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::VALIDACAO_CODIGO_EXTERNO, $params);
	}

	public function loadRecebimentosDisponiveisAdd($CDINTEGRACAO) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO
		);	
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_RECEBIMENTOS_ADD, $params);
	}
	
	public function loadRecebimentosDisponiveisInn($CDINTEGRACAO, $CDTIPORECE) {
		$params = array( 
			':CDINTEGRACAO' => $CDINTEGRACAO,
			':CDTIPORECE' 	=> $CDTIPORECE
		);	
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_RECEBIMENTOS_INN, $params);
	}
	
//-----------------
	public function setFilialOperador($CDFILIAL, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDOPERADOR' 	 => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::SET_FILIAL_OPERADOR, $params);
	}
	public function deleteFilialOperador($CDFILIAL, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDOPERADOR' 	 => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_FILIAL_OPERADOR, $params);
	}
	public function setLojaOperador($CDFILIAL, $CDLOJA, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDLOJA' 	     => $CDLOJA,
			':CDOPERADOR'    => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::SET_LOJA_OPERADOR, $params);
	}
	public function deleteLojaOperador($CDFILIAL, $CDLOJA, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDLOJA' 	     => $CDLOJA,
			':CDOPERADOR'    => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_LOJA_OPERADOR, $params);
	}

	public function getStores($CDFILIAL){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_LOJAS_FILIAL, $params);

	}

	public function getFilialPayments($CDFILIAL) {
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);

		$response = array( 
			array(
				'name' => "BRADESCO",
				'STATUS' => true,
				'value'  => 1
			),
			 array(
				'name'   => "ITAU",
				'STATUS' => true,
				'value'  => 2
			),
			array(
				'name'   => "BANCO DO BRASIL",
				'STATUS' => true,
				'value'  => 3
			)
		);

		return $response;
	}

	public function saveNutriRecomendation($DSRECOMENDNUTRI,$CDFILIAL){
		$params = array(
			'CDFILIAL' 	 => $CDFILIAL,
			'DSRECOMENDNUTRI' => $DSRECOMENDNUTRI
		);
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::UPDATE_NUTRI_RECOMENDATION, $params);
	}
	
	public function buscaFiliaisCliente($params) {
        $CDCLIENTE    = $params[0]['value'];
        $CDCONSUMIDOR = $params[1]['value'];
		$NRORG        = $params[2]['value'];
		$params = array(
			':CDCLIENTE'    => $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':NRORG'        => $NRORG
		);
		$result = $this->filialFactory->buscaFiliaisCliente($params);
		
		return $result;
	}
	
	public function buscaFiliaisConsumidor($params) {
        $CDCLIENTE    = $params[0]['value'];
		$CDCONSUMIDOR = $params[1]['value'];
		$NRORG        = $params[2]['value'];
		$params = array(
			':CDCLIENTE'    => $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':NRORG'        => $NRORG
		);
		$result = $this->filialFactory->buscaFiliaisConsumidor($params);
		
		return $result;
	}
	
	public function saveFiliaisConsumidor($params) {
        $CDCLIENTE         = $params[0]['value'];
        $CDCONSUMIDOR      = $params[1]['value'];
		$CDFILIAL          = $params[2]['value'];
		$NRORG             = $params[3]['value'];
		$params = array(
			':CDCLIENTE' 	=> $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':CDFILIAL' 	=> $CDFILIAL
		);
		$this->filialFactory->saveFiliaisConsumidor($params);
	}
	
	public function removeFiliaisConsumidor ($params) {
        $CDCLIENTE         = $params[0]['CDCLIENTE'];
        $CDCONSUMIDOR      = $params[0]['CDCONSUMIDOR'];
        $CDFILIAL          = $params[0]['CDFILIAL'];
        
		$params = array(
			':CDCLIENTE' 	   => $CDCLIENTE,
			':CDCONSUMIDOR'    => $CDCONSUMIDOR,
			':CDFILIAL' 	   => $CDFILIAL
		);
		$this->filialFactory->removeFiliaisConsumidor($params);
	}
	
	private function totalRegistrosParaVend ($conditions){
		return $this->entityManager->getConnection()->fetchAll(self::COUNT_PARAVEND, $conditions)[0]['TOTAL'];
	}
	private function selectFiliais ($conditions){
		return $this->entityManager->getConnection()->fetchAll(self::SELECT_FILIAL, []);
	}
	
	public function validaParavend ($request){
		$params = $this->util->getParamsAsArray($request);
		$filiais = self::selectFiliais($request);
		foreach($filiais as $filial){
				$this->insertParavend($filial);
		}
			
	} 
	
	private function insertParavend ($filial){
		$this->entityManager->getConnection()->executeQuery(self::INSERT_PARAVEND, $filial);
	}
	
	public function updateDefNfce($params){
		$query = $this->entityManager->getConnection()->executeQuery(self::UPDATE_CERTIFICADO_NFCE, $params);
		return $query;
	}
	
	public function updateIntegracaoDeliveryFilial ($rows){
		$rows = $rows[0];
		$params = array(
			'CDFILIALEXT' =>$rows['CDFILIALEXT'],
			'CDFILIALEXTSPOON' => $rows['CDFILIALEXTSPOON'],
			'CDFILIAL'=>$rows['CDFILIAL'],
			'NRORG'=>$rows['NRORG']
		);
		
		$this->entityManager->getConnection()->executeQuery(self::UPDATE_INTEGRACAO_DELIVERY_FILIAL, $params);
	}
	
	public function getUrl($params) {
		$query = $this->entityManager->getConnection()->fetchAll(self::SELECT_URL, $params);
		return $query;
	}
	
	public function getCNPJ($params) {
		$query = $this->entityManager->getConnection()->fetchAll(self::SELECT_CNPJ, $params);
		return $query;
	}
	
	public function getSenhaCertificado($params) {
		$query = $this->entityManager->getConnection()->fetchAll(self::SELECT_SENHA_CERTIFICADO, $params);
		return $query;
	}
	
	public function saveDayPart($dataSetDayPart){
        $params = array(
            ':HRINI1DAYPART'  => $dataSetDayPart['HRINI1DAYPART'],
            ':HRFIN1DAYPART'  => $dataSetDayPart['HRFIN1DAYPART'],
            ':HRINI2DAYPART'  => $dataSetDayPart['HRINI2DAYPART'],
            ':HRFIN2DAYPART'  => $dataSetDayPart['HRFIN2DAYPART'],
            ':HRINI3DAYPART'  => $dataSetDayPart['HRINI3DAYPART'],  
            ':HRFIN3DAYPART'  => $dataSetDayPart['HRFIN3DAYPART'],  
            ':HRINI4DAYPART'  => $dataSetDayPart['HRINI4DAYPART'],
            ':HRFIN4DAYPART'  => $dataSetDayPart['HRFIN4DAYPART'],
            ':CDFILIAL'       => $dataSetDayPart['CDFILIAL'],
            ':NRORG'          => $dataSetDayPart['NRORG']
            
        );
        return $this->entityManager->getConnection()->executeQuery(self::UPDATE_DAY_PART, $params);
	}
	
	public function exportDayPart($conditions){
		$params = array(
			':CDFILIAL' => $conditions['PARENTCDFILIAL'],
			':NRORG'    => $conditions['NRORG']
		);
		$rows = $this->entityManager->getConnection()->fetchAll(self::FIND_DAY_PART, $params);
		unset($params);
		$conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
		$params = array(
			':HRINI1DAYPART'  => $rows[0]['HRINI1DAYPART'],
            ':HRFIN1DAYPART'  => $rows[0]['HRFIN1DAYPART'],
            ':HRINI2DAYPART'  => $rows[0]['HRINI2DAYPART'],
            ':HRFIN2DAYPART'  => $rows[0]['HRFIN2DAYPART'],
            ':HRINI3DAYPART'  => $rows[0]['HRINI3DAYPART'],  
            ':HRFIN3DAYPART'  => $rows[0]['HRFIN3DAYPART'],  
            ':HRINI4DAYPART'  => $rows[0]['HRINI4DAYPART'],
            ':HRFIN4DAYPART'  => $rows[0]['HRFIN4DAYPART'],
            ':CDFILIAL'       => $conditions['CDFILIAL'],
            ':NRORG'          => $conditions['NRORG']	
		);
		return $this->entityManager->getConnection()->executeQuery(self::UPDATE_MULTIPLE_DAY_PARTS, $params);
	}
	
	public function verifyEmailCode($row){
		$row = $row[0];
		$params = array(
			':CDFILIAL' => $row['CDFILIAL'],
			':NRORG'	=> $row['NRORG'],
			':CDEMAIL'	=> $row['CDEMAIL']
		);
		$find = $this->entityManager->getConnection()->fetchAll(self::FIND_EMAIL_CODE, $params);
		if(count($find) > 0){
			return false;
		} else {
			return true;
		}
	}
	
	public function deleteEmailGerentes($row){
		$params = array(
			':CDFILIAL' => $row['CDFILIAL'],
			':NRORG'	=> $row['NRORG'],
			':CDEMAIL'	=> $row['CDEMAIL']
		);
		return $this->entityManager->getConnection()->executeQuery(self::DELETE_EMAIL, $params);
	}
	
	public function updateEmailGerentes($row){
		$params = array(
			':CDFILIAL'		=> $row['CDFILIAL'],
			':NRORG'		=> $row['NRORG'],
			':CDEMAIL'		=> $row['CDEMAIL'],
			':EMAILGERENTE'	=> $row['EMAILGERENTE']
			
		);
		return $this->entityManager->getConnection()->executeQuery(self::UPDATE_EMAIL, $params);
	}
	
	
	public function updateIntegracaoSite($row){
		
		if(!empty($row['CDFILIAL'])){
			foreach($row['CDFILIAL'] as $value){
				$params = array(
					':IDFILENVEMAIL' => $row['IDFILENVEMAIL'],
					':HRINTSLDNEG'		 => $row['HRINTSLDNEG'],
					':TXEMAILSLDNEGATIVO'		 => $row['TXEMAILSLDNEGATIVO'],
					':IDFILUTSITE'	 => $row['IDFILUTSITE'],
					':CDFILIAL'	 => $value
				);
				$this->entityManager->getConnection()->executeQuery(self::UPDATE_INTEGRACAO_SITE, $params);
			}
			return true;
		}else{
			return false;
		}
	}

	
	public function setCdPerfilSelecionado($cdperfilselecionado, $cdoperador, $nrorg) {
		if( !empty($cdperfilselecionado) && 
			!empty($cdoperador) &&
			!empty($nrorg)) {
				
			$params = array(
				':CDPERFILSELECIONADO' => $cdperfilselecionado,
				':NRORG'	 => $nrorg,
				':CDOPERADOR'	 => $cdoperador,
			);
			$this->entityManager->getConnection()->executeQuery(self::UPDATE_PERFIL_SELECIONADO, $params);
		} else 
			throw new \Exception("Não foi possível alterar a unidade e o perfil deste operador !");
	} 
	
	
	const UPDATE_PERFIL_SELECIONADO = "
		UPDATE OPERADOR 
		SET CDPERFILSELECIONADO = :CDPERFILSELECIONADO
		WHERE CDOPERADOR = :CDOPERADOR
		AND NRORG = :NRORG
	";
	
	
	
	const INSERT_PARAVEND = "
		INSERT INTO PARAVEND (CDFILIAL,CDPARAVEND) VALUES (:CDFILIAL, 1)
	";
	
	const COUNT_PARAVEND = "SELECT COUNT(*) AS TOTAL
							  FROM PARAVEND
							WHERE NRORG = :NRORG
							  AND CDFILIAL = :CDFILIAL";

	const UPDATE_CERTIFICADO_NFCE = "UPDATE
										PARAVEND SET NMARQCERTNFCE = :NMARQCERTNFCE, DSSENHACERTNFCE = :DSSENHACERTNFCE
									WHERE
									  CDFILIAL = :CDFILIAL
									AND NRORG = :NRORG";
									
	const SELECT_FILIAL = "SELECT CDFILIAL FROM FILIAL WHERE CDFILIAL NOT IN (SELECT CDFILIAL FROM PARAVEND)";
	
	const UPDATE_INTEGRACAO_DELIVERY_FILIAL = "
		UPDATE FILIAL 
			SET CDFILIALEXT = :CDFILIALEXT , CDFILIALEXTSPOON = :CDFILIALEXTSPOON
		WHERE
			CDFILIAL = :CDFILIAL
			AND NRORG = :NRORG
		
	";
	
	const SELECT_URL = "
		SELECT
		    FILESERVERURL
		FROM
		    PARAMGERAL
		WHERE 
		    NRORG = :NRORG
		
	";
	
	const SELECT_CNPJ = "
		SELECT
		    NRINSJURFILI
		FROM
		    FILIAL
		WHERE 
		    CDFILIAL  = :CDFILIAL
		    AND NRORG = :NRORG
		
	";
	
	const SELECT_SENHA_CERTIFICADO = "
		SELECT
		    DSSENHACERTNFCE
		FROM
		    PARAVEND
		WHERE 
		    CDFILIAL  = :CDFILIAL
		    AND NRORG = :NRORG
		
	";
	
	const UPDATE_DAY_PART = "
		UPDATE PARAVEND 
		       SET HRINI1DAYPART = :HRINI1DAYPART,
		          HRINI2DAYPART = :HRINI2DAYPART,
		          HRFIN1DAYPART = :HRFIN1DAYPART,
		          HRFIN2DAYPART = :HRFIN2DAYPART,
		          HRINI3DAYPART = :HRINI3DAYPART,
		          HRFIN3DAYPART = :HRFIN3DAYPART,
		          HRINI4DAYPART = :HRINI4DAYPART,
		          HRFIN4DAYPART = :HRFIN4DAYPART  
		       WHERE (CDFILIAL = :CDFILIAL)
		       AND   (NRORG = :NRORG)
	";
	
	const FIND_DAY_PART = "
		SELECT HRINI1DAYPART, HRFIN1DAYPART, HRINI2DAYPART, HRFIN2DAYPART, HRINI3DAYPART, HRFIN3DAYPART, HRINI4DAYPART, HRFIN4DAYPART
		FROM PARAVEND
		WHERE INSTR(:CDFILIAL, CDFILIAL) > 0 
			AND NRORG = :NRORG
	";
	
	const UPDATE_MULTIPLE_DAY_PARTS = "
		UPDATE PARAVEND 
		 SET HRINI1DAYPART = :HRINI1DAYPART,
			HRINI2DAYPART = :HRINI2DAYPART,
			HRFIN1DAYPART = :HRFIN1DAYPART,
			HRFIN2DAYPART = :HRFIN2DAYPART,
			HRINI3DAYPART = :HRINI3DAYPART,
			HRFIN3DAYPART = :HRFIN3DAYPART,
			HRINI4DAYPART = :HRINI4DAYPART,
			HRFIN4DAYPART = :HRFIN4DAYPART  
		WHERE INSTR(:CDFILIAL, CDFILIAL) > 0 
			AND   (NRORG = :NRORG)
	";
	
	const FIND_EMAIL_CODE = "
		SELECT CDEMAIL, CDFILIAL, EMAILGERENTE, NRORG
		FROM FILIGERENTE 
		WHERE CDFILIAL = :CDFILIAL 
		  AND NRORG = :NRORG
		  AND CDEMAIL = :CDEMAIL
	";
	
	const DELETE_EMAIL = "
		DELETE FROM FILIGERENTE
		WHERE CDFILIAL = :CDFILIAL
			AND CDEMAIL = :CDEMAIL
			AND NRORG = :NRORG
	";
	
	const UPDATE_EMAIL = "
		UPDATE FILIGERENTE
		SET EMAILGERENTE = :EMAILGERENTE
		WHERE CDFILIAL = :CDFILIAL
			AND NRORG = :NRORG
			AND CDEMAIL = :CDEMAIL
	";
	
	const UPDATE_INTEGRACAO_SITE = "
	UPDATE PARAVEND 
	SET IDFILENVEMAIL = :IDFILENVEMAIL,
		HRINTSLDNEG = :HRINTSLDNEG,
		TXEMAILSLDNEGATIVO = :TXEMAILSLDNEGATIVO,
		IDFILUTSITE = :IDFILUTSITE
	WHERE CDFILIAL = :CDFILIAL
	";
}